# Changelog

## [0.3.1](https://github.com/imnotjames/bytewax-webflow/compare/v0.3.0...v0.3.1) (2024-11-29)


### Bug Fixes

* actually update collection items instead of always creating new items ([45a86b4](https://github.com/imnotjames/bytewax-webflow/commit/45a86b40285c1572e77e8284222068f46dfff637))

## [0.3.0](https://github.com/imnotjames/bytewax-webflow/compare/v0.2.0...v0.3.0) (2024-11-27)


### Features

* drop `webflow` prefix from classes ([7b07ec5](https://github.com/imnotjames/bytewax-webflow/commit/7b07ec5866ca462c78c6a67f0025c8b2deae05da))


### Documentation

* link to bytewax ([408fcfc](https://github.com/imnotjames/bytewax-webflow/commit/408fcfcf37dbd48a9351988ddbb68aa899a3985d))

## [0.2.0](https://github.com/imnotjames/bytewax-webflow/compare/v0.1.1...v0.2.0) (2024-11-26)


### Features

* support publishing collection items automatically ([8244f55](https://github.com/imnotjames/bytewax-webflow/commit/8244f55c595d0bd42707278674efbaedb6da7225))


### Documentation

* add how to use the bytewax webflow in usage ([54c3a4a](https://github.com/imnotjames/bytewax-webflow/commit/54c3a4aad59eeb376861ca7e79ab04c1fe87b4b3))
* drop main checks badge ([bf3e6cc](https://github.com/imnotjames/bytewax-webflow/commit/bf3e6cc488b9b99f4bfff47f1097771cef68c628))

## [0.1.1](https://github.com/imnotjames/bytewax-webflow/compare/v0.1.0...v0.1.1) (2024-11-26)


### Documentation

* add badges because why not ([fcf34d6](https://github.com/imnotjames/bytewax-webflow/commit/fcf34d6fe7ee4055ebb94deb9db4709ae0c1d317))
* update package description ([005f38d](https://github.com/imnotjames/bytewax-webflow/commit/005f38d8334861ebd8ed86f1bae8e90a1d42e7b5))
